info = {
    "name": "bm",
    "date_order": "DMY",
    "january": [
        "zan",
        "zanwuye"
    ],
    "february": [
        "feb",
        "feburuye"
    ],
    "march": [
        "mar",
        "marisi"
    ],
    "april": [
        "awi",
        "awirili"
    ],
    "may": [
        "mɛ"
    ],
    "june": [
        "zuw",
        "zuwɛn"
    ],
    "july": [
        "zul",
        "zuluye"
    ],
    "august": [
        "uti"
    ],
    "september": [
        "sɛt",
        "sɛtanburu"
    ],
    "october": [
        "ɔku",
        "ɔkutɔburu"
    ],
    "november": [
        "now",
        "nowanburu"
    ],
    "december": [
        "des",
        "desanburu"
    ],
    "monday": [
        "ntɛ",
        "ntɛnɛ"
    ],
    "tuesday": [
        "tar",
        "tarata"
    ],
    "wednesday": [
        "ara",
        "araba"
    ],
    "thursday": [
        "ala",
        "alamisa"
    ],
    "friday": [
        "jum",
        "juma"
    ],
    "saturday": [
        "sib",
        "sibiri"
    ],
    "sunday": [
        "kar",
        "kari"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "san"
    ],
    "month": [
        "kalo"
    ],
    "week": [
        "dɔgɔkun"
    ],
    "day": [
        "don"
    ],
    "hour": [
        "lɛrɛ"
    ],
    "minute": [
        "miniti"
    ],
    "second": [
        "sekondi"
    ],
    "relative-type": {
        "0 day ago": [
            "bi"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "kunu"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "sini"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
