info = {
    "name": "bs-Cyrl",
    "date_order": "DMY",
    "january": [
        "јан",
        "јануар"
    ],
    "february": [
        "феб",
        "фебруар"
    ],
    "march": [
        "мар",
        "март"
    ],
    "april": [
        "апр",
        "април"
    ],
    "may": [
        "мај"
    ],
    "june": [
        "јун",
        "јуни"
    ],
    "july": [
        "јул",
        "јули"
    ],
    "august": [
        "авг",
        "август"
    ],
    "september": [
        "сеп",
        "септембар"
    ],
    "october": [
        "окт",
        "октобар"
    ],
    "november": [
        "нов",
        "новембар"
    ],
    "december": [
        "дец",
        "децембар"
    ],
    "monday": [
        "пон",
        "понедељак"
    ],
    "tuesday": [
        "уто",
        "уторак"
    ],
    "wednesday": [
        "сри",
        "сриједа"
    ],
    "thursday": [
        "чет",
        "четвртак"
    ],
    "friday": [
        "пет",
        "петак"
    ],
    "saturday": [
        "суб",
        "субота"
    ],
    "sunday": [
        "нед",
        "недеља"
    ],
    "am": [
        "пре подне"
    ],
    "pm": [
        "поподне"
    ],
    "year": [
        "година"
    ],
    "month": [
        "месец"
    ],
    "week": [
        "недеља"
    ],
    "day": [
        "дан"
    ],
    "hour": [
        "час"
    ],
    "minute": [
        "минут"
    ],
    "second": [
        "секунд"
    ],
    "relative-type": {
        "0 day ago": [
            "данас"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "овог месеца"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "ове недеље"
        ],
        "0 year ago": [
            "ове године"
        ],
        "1 day ago": [
            "јуче"
        ],
        "1 month ago": [
            "прошлог месеца"
        ],
        "1 week ago": [
            "прошле недеље"
        ],
        "1 year ago": [
            "прошле године"
        ],
        "in 1 day": [
            "сутра"
        ],
        "in 1 month": [
            "следећег месеца"
        ],
        "in 1 week": [
            "следеће недеље"
        ],
        "in 1 year": [
            "следеће године"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "пре (\\d+[.,]?\\d*) дан",
            "пре (\\d+[.,]?\\d*) дана"
        ],
        "\\1 hour ago": [
            "пре (\\d+[.,]?\\d*) сат",
            "пре (\\d+[.,]?\\d*) сати"
        ],
        "\\1 minute ago": [
            "пре (\\d+[.,]?\\d*) минут",
            "пре (\\d+[.,]?\\d*) минута"
        ],
        "\\1 month ago": [
            "пре (\\d+[.,]?\\d*) месец",
            "пре (\\d+[.,]?\\d*) месеци"
        ],
        "\\1 second ago": [
            "пре (\\d+[.,]?\\d*) секунд",
            "пре (\\d+[.,]?\\d*) секунди"
        ],
        "\\1 week ago": [
            "пре (\\d+[.,]?\\d*) недеља",
            "пре (\\d+[.,]?\\d*) недељу"
        ],
        "\\1 year ago": [
            "пре (\\d+[.,]?\\d*) година",
            "пре (\\d+[.,]?\\d*) годину"
        ],
        "in \\1 day": [
            "за (\\d+[.,]?\\d*) дан",
            "за (\\d+[.,]?\\d*) дана"
        ],
        "in \\1 hour": [
            "за (\\d+[.,]?\\d*) сат",
            "за (\\d+[.,]?\\d*) сати"
        ],
        "in \\1 minute": [
            "за (\\d+[.,]?\\d*) минут",
            "за (\\d+[.,]?\\d*) минута"
        ],
        "in \\1 month": [
            "за (\\d+[.,]?\\d*) месец",
            "за (\\d+[.,]?\\d*) месеци"
        ],
        "in \\1 second": [
            "за (\\d+[.,]?\\d*) секунд",
            "за (\\d+[.,]?\\d*) секунди"
        ],
        "in \\1 week": [
            "за (\\d+[.,]?\\d*) недеља",
            "за (\\d+[.,]?\\d*) недељу"
        ],
        "in \\1 year": [
            "за (\\d+[.,]?\\d*) година",
            "за (\\d+[.,]?\\d*) годину"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
