info = {
    "name": "mgh",
    "date_order": "DMY",
    "january": [
        "kwa",
        "mweri wo kwanza"
    ],
    "february": [
        "mweri wo unayeli",
        "una"
    ],
    "march": [
        "mweri wo uneraru",
        "rar"
    ],
    "april": [
        "che",
        "mweri wo unecheshe"
    ],
    "may": [
        "mweri wo unethanu",
        "tha"
    ],
    "june": [
        "moc",
        "mweri wo thanu na mocha"
    ],
    "july": [
        "mweri wo saba",
        "sab"
    ],
    "august": [
        "mweri wo nane",
        "nan"
    ],
    "september": [
        "mweri wo tisa",
        "tis"
    ],
    "october": [
        "kum",
        "mweri wo kumi"
    ],
    "november": [
        "moj",
        "mweri wo kumi na moja"
    ],
    "december": [
        "mweri wo kumi na yel'li",
        "yel"
    ],
    "monday": [
        "jtt",
        "jumatatu"
    ],
    "tuesday": [
        "jnn",
        "jumanne"
    ],
    "wednesday": [
        "jtn",
        "jumatano"
    ],
    "thursday": [
        "ara",
        "arahamisi"
    ],
    "friday": [
        "iju",
        "ijumaa"
    ],
    "saturday": [
        "jmo",
        "jumamosi"
    ],
    "sunday": [
        "sab",
        "sabato"
    ],
    "am": [
        "wichishu"
    ],
    "pm": [
        "mchochil'l"
    ],
    "year": [
        "yaka"
    ],
    "month": [
        "mweri"
    ],
    "week": [
        "iwiki mocha"
    ],
    "day": [
        "nihuku"
    ],
    "hour": [
        "isaa"
    ],
    "minute": [
        "idakika"
    ],
    "second": [
        "isekunde"
    ],
    "relative-type": {
        "0 day ago": [
            "lel'lo"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "n'chana"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "me'llo"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
