info = {
    "name": "mer",
    "date_order": "DMY",
    "january": [
        "jan",
        "januarĩ"
    ],
    "february": [
        "feb",
        "feburuarĩ"
    ],
    "march": [
        "mac",
        "machi"
    ],
    "april": [
        "ĩpu",
        "ĩpurũ"
    ],
    "may": [
        "mĩĩ"
    ],
    "june": [
        "nju",
        "njuni"
    ],
    "july": [
        "njr",
        "njuraĩ"
    ],
    "august": [
        "aga",
        "agasti"
    ],
    "september": [
        "septemba",
        "spt"
    ],
    "october": [
        "okt",
        "oktũba"
    ],
    "november": [
        "nov",
        "novemba"
    ],
    "december": [
        "dec",
        "dicemba"
    ],
    "monday": [
        "mra",
        "muramuko"
    ],
    "tuesday": [
        "wai",
        "wairi"
    ],
    "wednesday": [
        "wet",
        "wethatu"
    ],
    "thursday": [
        "wen",
        "wena"
    ],
    "friday": [
        "wetano",
        "wtn"
    ],
    "saturday": [
        "jum",
        "jumamosi"
    ],
    "sunday": [
        "kiu",
        "kiumia"
    ],
    "am": [
        "rũ"
    ],
    "pm": [
        "ũg"
    ],
    "year": [
        "mwaka"
    ],
    "month": [
        "mweri"
    ],
    "week": [
        "kiumia"
    ],
    "day": [
        "ntukũ"
    ],
    "hour": [
        "ĩthaa"
    ],
    "minute": [
        "ndagika"
    ],
    "second": [
        "sekondi"
    ],
    "relative-type": {
        "0 day ago": [
            "narua"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "ĩgoro"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "rũjũ"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
