info = {
    "name": "mg",
    "date_order": "YMD",
    "january": [
        "jan",
        "janoary"
    ],
    "february": [
        "feb",
        "febroary"
    ],
    "march": [
        "mar",
        "martsa"
    ],
    "april": [
        "apr",
        "aprily"
    ],
    "may": [
        "mey"
    ],
    "june": [
        "jon",
        "jona"
    ],
    "july": [
        "jol",
        "jolay"
    ],
    "august": [
        "aog",
        "aogositra"
    ],
    "september": [
        "sep",
        "septambra"
    ],
    "october": [
        "okt",
        "oktobra"
    ],
    "november": [
        "nov",
        "novambra"
    ],
    "december": [
        "des",
        "desambra"
    ],
    "monday": [
        "alats",
        "alatsinainy"
    ],
    "tuesday": [
        "tal",
        "talata"
    ],
    "wednesday": [
        "alar",
        "alarobia"
    ],
    "thursday": [
        "alak",
        "alakamisy"
    ],
    "friday": [
        "zom",
        "zoma"
    ],
    "saturday": [
        "asab",
        "asabotsy"
    ],
    "sunday": [
        "alah",
        "alahady"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "taona"
    ],
    "month": [
        "volana"
    ],
    "week": [
        "herinandro"
    ],
    "day": [
        "andro"
    ],
    "hour": [
        "ora"
    ],
    "minute": [
        "minitra"
    ],
    "second": [
        "segondra"
    ],
    "relative-type": {
        "0 day ago": [
            "anio"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "omaly"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "rahampitso"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
