info = {
    "name": "brx",
    "date_order": "MDY",
    "january": [
        "जानुवारी"
    ],
    "february": [
        "फेब्रुवारी"
    ],
    "march": [
        "मार्स"
    ],
    "april": [
        "एफ्रिल"
    ],
    "may": [
        "मे"
    ],
    "june": [
        "जुन"
    ],
    "july": [
        "जुलाइ"
    ],
    "august": [
        "आगस्थ"
    ],
    "september": [
        "सेबथेज्ब़र"
    ],
    "october": [
        "अखथबर"
    ],
    "november": [
        "नबेज्ब़र"
    ],
    "december": [
        "दिसेज्ब़र"
    ],
    "monday": [
        "सम",
        "समबार"
    ],
    "tuesday": [
        "मंगल",
        "मंगलबार"
    ],
    "wednesday": [
        "बुद",
        "बुदबार"
    ],
    "thursday": [
        "बिसथि",
        "बिसथिबार"
    ],
    "friday": [
        "सुखुर",
        "सुखुरबार"
    ],
    "saturday": [
        "सुनि",
        "सुनिबार"
    ],
    "sunday": [
        "रबि",
        "रबिबार"
    ],
    "am": [
        "फुं"
    ],
    "pm": [
        "बेलासे"
    ],
    "year": [
        "बोसोर"
    ],
    "month": [
        "दान"
    ],
    "week": [
        "सबथा/हबथा"
    ],
    "day": [
        "सान"
    ],
    "hour": [
        "रिंगा"
    ],
    "minute": [
        "मिनिथ"
    ],
    "second": [
        "सेखेन्द"
    ],
    "relative-type": {
        "0 day ago": [
            "दिनै"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "मैया"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "गाबोन"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
