info = {
    "name": "jgo",
    "date_order": "YMD",
    "january": [
        "nduŋmbi saŋ"
    ],
    "february": [
        "pɛsaŋ pɛ́pá"
    ],
    "march": [
        "pɛsaŋ pɛ́tát"
    ],
    "april": [
        "pɛsaŋ pɛ́nɛ́kwa"
    ],
    "may": [
        "pɛsaŋ pataa"
    ],
    "june": [
        "pɛsaŋ pɛ́nɛ́ntúkú"
    ],
    "july": [
        "pɛsaŋ saambá"
    ],
    "august": [
        "pɛsaŋ pɛ́nɛ́fɔm"
    ],
    "september": [
        "pɛsaŋ pɛ́nɛ́pfúꞌú"
    ],
    "october": [
        "pɛsaŋ nɛgɛ́m"
    ],
    "november": [
        "pɛsaŋ ntsɔ̌pmɔ́"
    ],
    "december": [
        "pɛsaŋ ntsɔ̌ppá"
    ],
    "monday": [
        "mɔ́ndi"
    ],
    "tuesday": [
        "ápta mɔ́ndi"
    ],
    "wednesday": [
        "wɛ́nɛsɛdɛ"
    ],
    "thursday": [
        "tɔ́sɛdɛ"
    ],
    "friday": [
        "fɛlâyɛdɛ"
    ],
    "saturday": [
        "sásidɛ"
    ],
    "sunday": [
        "sɔ́ndi"
    ],
    "am": [
        "mba'mba'"
    ],
    "pm": [
        "ŋka mbɔ́t nji"
    ],
    "year": [
        "year"
    ],
    "month": [
        "month"
    ],
    "week": [
        "week"
    ],
    "day": [
        "day"
    ],
    "hour": [
        "hour"
    ],
    "minute": [
        "minute"
    ],
    "second": [
        "second"
    ],
    "relative-type": {
        "0 day ago": [
            "lɔꞌɔ"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "yesterday"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "tomorrow"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "ɛ́ gɛ́ mɔ́ lɛ́ꞌ (\\d+[.,]?\\d*)"
        ],
        "\\1 hour ago": [
            "ɛ́ gɛ mɔ́ (\\d+[.,]?\\d*) háwa"
        ],
        "\\1 minute ago": [
            "ɛ́ gɛ́ mɔ́ minút (\\d+[.,]?\\d*)"
        ],
        "\\1 month ago": [
            "ɛ́ gɛ́ mɔ́ pɛsaŋ (\\d+[.,]?\\d*)"
        ],
        "\\1 week ago": [
            "ɛ́ gɛ́ mɔ (\\d+[.,]?\\d*) ŋgap-mbi"
        ],
        "\\1 year ago": [
            "ɛ́gɛ́ mɔ́ ŋguꞌ (\\d+[.,]?\\d*)"
        ],
        "in \\1 day": [
            "nǔu lɛ́ꞌ (\\d+[.,]?\\d*)"
        ],
        "in \\1 hour": [
            "nǔu háwa (\\d+[.,]?\\d*)"
        ],
        "in \\1 minute": [
            "nǔu (\\d+[.,]?\\d*) minút"
        ],
        "in \\1 month": [
            "nǔu (\\d+[.,]?\\d*) saŋ"
        ],
        "in \\1 week": [
            "nǔu ŋgap-mbi (\\d+[.,]?\\d*)"
        ],
        "in \\1 year": [
            "nǔu ŋguꞌ (\\d+[.,]?\\d*)"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
