info = {
    "sentence_splitter_group": 1,
    "skip": [
        "ganap",
        "na",
        "noon",
        "noong",
        "sa",
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ],
    "monday": [
        "Lunes",
        "Lun"
    ],
    "tuesday": [
        "Martes"
    ],
    "wednesday": [
        "Miyerkules",
        "Miy"
    ],
    "thursday": [
        "Huwebes",
        "Huw"
    ],
    "friday": [
        "Biyernes",
        "Biy"
    ],
    "saturday": [
        "Sabado",
        "Sab"
    ],
    "sunday": [
        "Linggo",
        "Lin"
    ],
    "january": [
        "Enero",
        "Ene"
    ],
    "february": [
        "Pebrero",
        "Peb"
    ],
    "march": [
        "Marso",
        "Mar"
    ],
    "april": [
        "Abril",
        "Abr"
    ],
    "may": [
        "Mayo",
        "May"
    ],
    "june": [
        "Hunyo",
        "Hun"
    ],
    "july": [
        "Hulyo",
        "Hul"
    ],
    "august": [
        "Agosto",
        "Ago"
    ],
    "september": [
        "Setyembre",
        "Set"
    ],
    "october": [
        "Oktubre",
        "Okt"
    ],
    "november": [
        "Nobyembre",
        "Nob"
    ],
    "december": [
        "Disyembre",
        "Dis"
    ],
    "year": [
        "taon"
    ],
    "month": [
        "buwan"
    ],
    "week": [
        "linggo"
    ],
    "day": [
        "araw"
    ],
    "hour": [
        "oras"
    ],
    "minute": [
        "minuto"
    ],
    "second": [
        "segundo"
    ],
    "ago": [
        "nakaraan",
        "nakalipas"
    ],
    "in": [
        "sa"
    ],
    "simplifications": [
        {
            "kahapon": "1 araw nakaraan"
        },
        {
            "ngayon": "0 segundo nakalipas"
        },
        {
            "isang araw": "2 araw"
        }
    ],
    "name": "tl"
}
