info = {
    "name": "saq",
    "date_order": "DMY",
    "january": [
        "lapa le obo",
        "obo"
    ],
    "february": [
        "lapa le waare",
        "waa"
    ],
    "march": [
        "lapa le okuni",
        "oku"
    ],
    "april": [
        "lapa le ong'wan",
        "ong"
    ],
    "may": [
        "ime",
        "lapa le imet"
    ],
    "june": [
        "ile",
        "lapa le ile"
    ],
    "july": [
        "lapa le sapa",
        "sap"
    ],
    "august": [
        "isi",
        "lapa le isiet"
    ],
    "september": [
        "lapa le saal",
        "saa"
    ],
    "october": [
        "lapa le tomon",
        "tom"
    ],
    "november": [
        "lapa le tomon obo",
        "tob"
    ],
    "december": [
        "lapa le tomon waare",
        "tow"
    ],
    "monday": [
        "kun",
        "mderot ee kuni"
    ],
    "tuesday": [
        "mderot ee ong'wan",
        "ong"
    ],
    "wednesday": [
        "ine",
        "mderot ee inet"
    ],
    "thursday": [
        "ile",
        "mderot ee ile"
    ],
    "friday": [
        "mderot ee sapa",
        "sap"
    ],
    "saturday": [
        "kwe",
        "mderot ee kwe"
    ],
    "sunday": [
        "are",
        "mderot ee are"
    ],
    "am": [
        "tesiran"
    ],
    "pm": [
        "teipa"
    ],
    "year": [
        "lari"
    ],
    "month": [
        "lapa"
    ],
    "week": [
        "saipa napo"
    ],
    "day": [
        "mpari"
    ],
    "hour": [
        "saai"
    ],
    "minute": [
        "idakika"
    ],
    "second": [
        "isekondi"
    ],
    "relative-type": {
        "0 day ago": [
            "duo"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "ng'ole"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "taisere"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
