info = {
    "name": "to",
    "date_order": "DMY",
    "january": [
        "sān",
        "sānuali"
    ],
    "february": [
        "fēp",
        "fēpueli"
    ],
    "march": [
        "ma'a",
        "ma'asi"
    ],
    "april": [
        "'epe",
        "'epeleli"
    ],
    "may": [
        "mē"
    ],
    "june": [
        "sun",
        "sune"
    ],
    "july": [
        "siu",
        "siulai"
    ],
    "august": [
        "'aok",
        "'aokosi"
    ],
    "september": [
        "sep",
        "sepitema"
    ],
    "october": [
        "'oka",
        "'okatopa"
    ],
    "november": [
        "nōv",
        "nōvema"
    ],
    "december": [
        "tīs",
        "tīsema"
    ],
    "monday": [
        "mōn",
        "mōnite"
    ],
    "tuesday": [
        "tūs",
        "tūsite"
    ],
    "wednesday": [
        "pul",
        "pulelulu"
    ],
    "thursday": [
        "tu'a",
        "tu'apulelulu"
    ],
    "friday": [
        "fal",
        "falaite"
    ],
    "saturday": [
        "tok",
        "tokonaki"
    ],
    "sunday": [
        "sāp",
        "sāpate"
    ],
    "am": [
        "am",
        "hengihengi",
        "hh"
    ],
    "pm": [
        "ea",
        "efiafi",
        "pm"
    ],
    "year": [
        "ta'u"
    ],
    "month": [
        "māhina"
    ],
    "week": [
        "uike"
    ],
    "day": [
        "'aho"
    ],
    "hour": [
        "houa"
    ],
    "minute": [
        "miniti"
    ],
    "second": [
        "sekoni"
    ],
    "relative-type": {
        "0 day ago": [
            "'ahó ni"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "māhiná ni"
        ],
        "0 second ago": [
            "taimí ni"
        ],
        "0 week ago": [
            "uiké ni"
        ],
        "0 year ago": [
            "ta'ú ni"
        ],
        "1 day ago": [
            "'aneafi"
        ],
        "1 month ago": [
            "māhina kuo'osi"
        ],
        "1 week ago": [
            "uike kuo'osi"
        ],
        "1 year ago": [
            "ta'u kuo'osi"
        ],
        "in 1 day": [
            "'apongipongi"
        ],
        "in 1 month": [
            "māhina kaha'u"
        ],
        "in 1 week": [
            "uike kaha'u"
        ],
        "in 1 year": [
            "ta'u kaha'u"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "'aho 'e (\\d+[.,]?\\d*) kuo'osi"
        ],
        "\\1 hour ago": [
            "houa 'e (\\d+[.,]?\\d*) kuo'osi"
        ],
        "\\1 minute ago": [
            "miniti 'e (\\d+[.,]?\\d*) kuo'osi"
        ],
        "\\1 month ago": [
            "māhina 'e (\\d+[.,]?\\d*) kuo'osi"
        ],
        "\\1 second ago": [
            "sekoni 'e (\\d+[.,]?\\d*) kuo'osi"
        ],
        "\\1 week ago": [
            "uike 'e (\\d+[.,]?\\d*) kuo'osi"
        ],
        "\\1 year ago": [
            "ta'u 'e (\\d+[.,]?\\d*) kuo'osi"
        ],
        "in \\1 day": [
            "'i he 'aho 'e (\\d+[.,]?\\d*)"
        ],
        "in \\1 hour": [
            "'i he houa 'e (\\d+[.,]?\\d*)"
        ],
        "in \\1 minute": [
            "'i he miniti 'e (\\d+[.,]?\\d*)"
        ],
        "in \\1 month": [
            "'i he māhina 'e (\\d+[.,]?\\d*)"
        ],
        "in \\1 second": [
            "'i he sekoni 'e (\\d+[.,]?\\d*)"
        ],
        "in \\1 week": [
            "'i he uike 'e (\\d+[.,]?\\d*)"
        ],
        "in \\1 year": [
            "'i he ta'u 'e (\\d+[.,]?\\d*)"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
