info = {
    "name": "mt",
    "date_order": "DMY",
    "january": [
        "jan",
        "jannar"
    ],
    "february": [
        "fra",
        "frar"
    ],
    "march": [
        "mar",
        "marzu"
    ],
    "april": [
        "apr",
        "april"
    ],
    "may": [
        "mej",
        "mejju"
    ],
    "june": [
        "ġun",
        "ġunju"
    ],
    "july": [
        "lul",
        "lulju"
    ],
    "august": [
        "aww",
        "awwissu"
    ],
    "september": [
        "set",
        "settembru"
    ],
    "october": [
        "ott",
        "ottubru"
    ],
    "november": [
        "nov",
        "novembru"
    ],
    "december": [
        "diċ",
        "diċembru"
    ],
    "monday": [
        "it-tnejn",
        "tne"
    ],
    "tuesday": [
        "it-tlieta",
        "tli"
    ],
    "wednesday": [
        "erb",
        "l-erbgħa"
    ],
    "thursday": [
        "il-ħamis",
        "ħam"
    ],
    "friday": [
        "il-ġimgħa",
        "ġim"
    ],
    "saturday": [
        "is-sibt",
        "sib"
    ],
    "sunday": [
        "il-ħadd",
        "ħad"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "sena"
    ],
    "month": [
        "xahar"
    ],
    "week": [
        "ġimgħa"
    ],
    "day": [
        "jum"
    ],
    "hour": [
        "siegħa"
    ],
    "minute": [
        "minuta"
    ],
    "second": [
        "sekonda"
    ],
    "relative-type": {
        "0 day ago": [
            "illum"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "dan ix-xahar"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "din il-ġimgħa"
        ],
        "0 year ago": [
            "din is-sena"
        ],
        "1 day ago": [
            "ilbieraħ"
        ],
        "1 month ago": [
            "ix-xahar li għadda"
        ],
        "1 week ago": [
            "il-ġimgħa li għaddiet"
        ],
        "1 year ago": [
            "is-sena li għaddiet"
        ],
        "in 1 day": [
            "għada"
        ],
        "in 1 month": [
            "ix-xahar id-dieħel"
        ],
        "in 1 week": [
            "il-ġimgħa d-dieħla"
        ],
        "in 1 year": [
            "is-sena d-dieħla"
        ]
    },
    "relative-type-regex": {
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) sena ilu",
            "(\\d+[.,]?\\d*) snin ilu"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
