info = {
    "name": "pl",
    "date_order": "DMY",
    "january": [
        "sty",
        "styczeń",
        "stycznia",
        "Styczeń",
        "Styczen",
        "Stycznia",
        "Styczniu",
        "Sty"
    ],
    "february": [
        "lut",
        "lutego",
        "luty",
        "Luty",
        "Lutego",
        "Lutym",
        "Lut"
    ],
    "march": [
        "mar",
        "marca",
        "marzec",
        "Marzec",
        "Marca",
        "Marcu",
        "Mar"
    ],
    "april": [
        "kwi",
        "kwiecień",
        "kwietnia",
        "Kwiecień",
        "Kwiecien",
        "Kwietnia",
        "Kwietniu",
        "Kwi",
        "Kwie"
    ],
    "may": [
        "maj",
        "maja",
        "Maj",
        "Maja",
        "Maju"
    ],
    "june": [
        "cze",
        "czerwca",
        "czerwiec",
        "Czerwiec",
        "Czerwca",
        "Czerwcu",
        "Cze"
    ],
    "july": [
        "lip",
        "lipca",
        "lipiec",
        "Lipiec",
        "Lipca",
        "Lipcu",
        "Lip"
    ],
    "august": [
        "sie",
        "sierpień",
        "sierpnia",
        "Sierpień",
        "Sierpien",
        "Sierpnia",
        "Sierpniu",
        "Sie"
    ],
    "september": [
        "wrz",
        "wrzesień",
        "września",
        "Wrzesień",
        "Wrzesien",
        "Września",
        "Wrzesnia",
        "Wrześniu",
        "Wrzesniu",
        "Wrz"
    ],
    "october": [
        "paź",
        "październik",
        "października",
        "Październik",
        "Pazdziernik",
        "Października",
        "Pazdziernika",
        "Październiku",
        "Pazdzierniku",
        "Paź",
        "Paz"
    ],
    "november": [
        "lis",
        "listopad",
        "listopada",
        "Listopad",
        "Listopada",
        "Listopadzie",
        "Lis"
    ],
    "december": [
        "gru",
        "grudnia",
        "grudzień",
        "Grudzień",
        "Grudzien",
        "Grudnia",
        "Grudniu",
        "Gru"
    ],
    "monday": [
        "pon",
        "poniedziałek",
        "Poniedziałek",
        "Poniedzialek",
        "Pon",
        "Pn"
    ],
    "tuesday": [
        "wt",
        "wtorek",
        "Wtorek",
        "Wt",
        "Wto"
    ],
    "wednesday": [
        "śr",
        "środa",
        "Środa",
        "Sroda",
        "Środę",
        "Srode",
        "Śro",
        "Sro",
        "Śr",
        "Sr"
    ],
    "thursday": [
        "czw",
        "czwartek",
        "Czwartek",
        "Czw",
        "Cz"
    ],
    "friday": [
        "piątek",
        "pt",
        "Piątek",
        "Piatek",
        "Pią",
        "Pia",
        "Pi",
        "Pt"
    ],
    "saturday": [
        "sob",
        "sobota",
        "Sobota",
        "Sobotę",
        "Sobote",
        "Sob",
        "So",
        "Sb"
    ],
    "sunday": [
        "niedz",
        "niedziela",
        "Niedziela",
        "Niedzielę",
        "Niedziele",
        "Nie",
        "Nd"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "r",
        "rok",
        "lata",
        "lat"
    ],
    "month": [
        "mc",
        "mies",
        "miesiąc",
        "miesiac",
        "miesięcy",
        "miesiąca",
        "miesiące",
        "miesiace"
    ],
    "week": [
        "tydz",
        "tydzień",
        "tydzien",
        "tygodni",
        "tygodnie"
    ],
    "day": [
        "dzień",
        "dzien",
        "dnia",
        "dniu",
        "dni"
    ],
    "hour": [
        "g",
        "godz",
        "godzina",
        "godzinę",
        "godzine",
        "godzin",
        "godziny"
    ],
    "minute": [
        "min",
        "minuta",
        "minuty",
        "minut",
        "minute",
        "minutę"
    ],
    "second": [
        "s",
        "sek",
        "sekunda",
        "sekundę",
        "sekunde",
        "sekundy",
        "sekund"
    ],
    "relative-type": {
        "0 day ago": [
            "dzisiaj"
        ],
        "0 hour ago": [
            "ta godzina"
        ],
        "0 minute ago": [
            "ta minuta"
        ],
        "0 month ago": [
            "w tym miesiącu"
        ],
        "0 second ago": [
            "teraz"
        ],
        "0 week ago": [
            "w tym tygodniu"
        ],
        "0 year ago": [
            "w tym roku"
        ],
        "1 day ago": [
            "wczoraj"
        ],
        "1 month ago": [
            "w zeszłym miesiącu"
        ],
        "1 week ago": [
            "w zeszłym tygodniu"
        ],
        "1 year ago": [
            "w zeszłym roku"
        ],
        "in 1 day": [
            "jutro"
        ],
        "in 1 month": [
            "w przyszłym miesiącu"
        ],
        "in 1 week": [
            "w przyszłym tygodniu"
        ],
        "in 1 year": [
            "w przyszłym roku"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) dnia temu",
            "(\\d+[.,]?\\d*) dzień temu"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) g temu",
            "(\\d+[.,]?\\d*) godz temu",
            "(\\d+[.,]?\\d*) godziny temu",
            "(\\d+[.,]?\\d*) godzinę temu"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) min temu",
            "(\\d+[.,]?\\d*) minuty temu",
            "(\\d+[.,]?\\d*) minutę temu"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) mies temu",
            "(\\d+[.,]?\\d*) miesiąc temu",
            "(\\d+[.,]?\\d*) miesiąca temu",
            "–(\\d+[.,]?\\d*) mies"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) s temu",
            "(\\d+[.,]?\\d*) sek temu",
            "(\\d+[.,]?\\d*) sekundy temu",
            "(\\d+[.,]?\\d*) sekundę temu"
        ],
        "\\1 week ago": [
            "(\\d+[.,]?\\d*) tydz temu",
            "(\\d+[.,]?\\d*) tydzień temu",
            "(\\d+[.,]?\\d*) tyg temu",
            "(\\d+[.,]?\\d*) tygodnia temu"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) rok temu",
            "(\\d+[.,]?\\d*) roku temu"
        ],
        "in \\1 day": [
            "za (\\d+[.,]?\\d*) dnia",
            "za (\\d+[.,]?\\d*) dzień"
        ],
        "in \\1 hour": [
            "za (\\d+[.,]?\\d*) g",
            "za (\\d+[.,]?\\d*) godz",
            "za (\\d+[.,]?\\d*) godziny",
            "za (\\d+[.,]?\\d*) godzinę"
        ],
        "in \\1 minute": [
            "za (\\d+[.,]?\\d*) min",
            "za (\\d+[.,]?\\d*) minuty",
            "za (\\d+[.,]?\\d*) minutę"
        ],
        "in \\1 month": [
            "za (\\d+[.,]?\\d*) mies",
            "za (\\d+[.,]?\\d*) miesiąc",
            "za (\\d+[.,]?\\d*) miesiąca"
        ],
        "in \\1 second": [
            "za (\\d+[.,]?\\d*) s",
            "za (\\d+[.,]?\\d*) sek",
            "za (\\d+[.,]?\\d*) sekundy",
            "za (\\d+[.,]?\\d*) sekundę"
        ],
        "in \\1 week": [
            "za (\\d+[.,]?\\d*) tydz",
            "za (\\d+[.,]?\\d*) tydzień",
            "za (\\d+[.,]?\\d*) tyg",
            "za (\\d+[.,]?\\d*) tygodnia"
        ],
        "in \\1 year": [
            "za (\\d+[.,]?\\d*) rok",
            "za (\\d+[.,]?\\d*) roku"
        ]
    },
    "locale_specific": {},
    "sentence_splitter_group": 1,
    "skip": [
        "i",
        "o",
        "r.",
        "roku",
        "w",
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ],
    "ago": [
        "temu"
    ],
    "in": [
        "za"
    ],
    "simplifications": [
        {
            "dziś": "0 dnia"
        },
        {
            "dzisiaj": "0 dnia"
        },
        {
            "onegdaj": "2 dnia"
        },
        {
            "przedwczoraj": "2 dnia temu"
        },
        {
            "jutro": "za 1 dnia"
        },
        {
            "pojutrze": "za 2 dnia"
        }
    ]
}
