info = {
    "name": "yi",
    "date_order": "DMY",
    "january": [
        "יאַנ",
        "יאַנואַר"
    ],
    "february": [
        "פֿעב",
        "פֿעברואַר"
    ],
    "march": [
        "מערץ"
    ],
    "april": [
        "אַפּר",
        "אַפּריל"
    ],
    "may": [
        "מיי"
    ],
    "june": [
        "יוני"
    ],
    "july": [
        "יולי"
    ],
    "august": [
        "אויג",
        "אויגוסט"
    ],
    "september": [
        "סעפּ",
        "סעפּטעמבער"
    ],
    "october": [
        "אקט",
        "אקטאבער"
    ],
    "november": [
        "נאוו",
        "נאוועמבער"
    ],
    "december": [
        "דעצ",
        "דעצעמבער"
    ],
    "monday": [
        "מאָנטיק"
    ],
    "tuesday": [
        "דינסטיק"
    ],
    "wednesday": [
        "מיטוואך"
    ],
    "thursday": [
        "דאנערשטיק"
    ],
    "friday": [
        "פֿרײַטיק"
    ],
    "saturday": [
        "שבת"
    ],
    "sunday": [
        "זונטיק"
    ],
    "am": [
        "פֿאַרמיטאָג"
    ],
    "pm": [
        "נאָכמיטאָג"
    ],
    "year": [
        "יאָר"
    ],
    "month": [
        "מאנאַט"
    ],
    "week": [
        "וואך"
    ],
    "day": [
        "טאָג"
    ],
    "hour": [
        "שעה"
    ],
    "minute": [
        "מינוט"
    ],
    "second": [
        "סעקונדע"
    ],
    "relative-type": {
        "0 day ago": [
            "היינט"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "דעם חודש"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "הײַ יאָר"
        ],
        "1 day ago": [
            "נעכטן"
        ],
        "1 month ago": [
            "פֿאַרגאנגענעם חודש"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "פֿאַראַיאָר"
        ],
        "in 1 day": [
            "מארגן"
        ],
        "in 1 month": [
            "קומענדיקן חודש"
        ],
        "in 1 week": [
            "איבער אַכט טאָג"
        ],
        "in 1 year": [
            "איבער א יאָר"
        ]
    },
    "relative-type-regex": {
        "\\1 month ago": [
            "פֿאַר (\\d+[.,]?\\d*) חדשים",
            "פֿאַר (\\d+[.,]?\\d*) חודש"
        ],
        "\\1 year ago": [
            "פֿאַר (\\d+[.,]?\\d*) יאָר"
        ],
        "in \\1 day": [
            "אין (\\d+[.,]?\\d*) טאָג אַרום",
            "אין (\\d+[.,]?\\d*) טעג אַרום"
        ],
        "in \\1 month": [
            "איבער (\\d+[.,]?\\d*) חדשים",
            "איבער (\\d+[.,]?\\d*) חודש"
        ],
        "in \\1 year": [
            "איבער (\\d+[.,]?\\d*) יאָר"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
