info = {
    "name": "rw",
    "date_order": "YMD",
    "january": [
        "mut",
        "mutarama"
    ],
    "february": [
        "gas",
        "gashyantare"
    ],
    "march": [
        "wer",
        "werurwe"
    ],
    "april": [
        "mat",
        "mata"
    ],
    "may": [
        "gic",
        "gicuransi"
    ],
    "june": [
        "kam",
        "kamena"
    ],
    "july": [
        "nya",
        "nyakanga"
    ],
    "august": [
        "kan",
        "kanama"
    ],
    "september": [
        "nze",
        "nzeli"
    ],
    "october": [
        "ukw",
        "ukwakira"
    ],
    "november": [
        "ugu",
        "ugushyingo"
    ],
    "december": [
        "uku",
        "ukuboza"
    ],
    "monday": [
        "kuwa mbere",
        "mbe"
    ],
    "tuesday": [
        "kab",
        "kuwa kabiri"
    ],
    "wednesday": [
        "gtu",
        "kuwa gatatu"
    ],
    "thursday": [
        "kan",
        "kuwa kane"
    ],
    "friday": [
        "gnu",
        "kuwa gatanu"
    ],
    "saturday": [
        "gnd",
        "kuwa gatandatu"
    ],
    "sunday": [
        "cyu",
        "ku cyumweru"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "year"
    ],
    "month": [
        "month"
    ],
    "week": [
        "week"
    ],
    "day": [
        "day"
    ],
    "hour": [
        "hour"
    ],
    "minute": [
        "minute"
    ],
    "second": [
        "second"
    ],
    "relative-type": {
        "0 day ago": [
            "today"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "yesterday"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "tomorrow"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
