info = {
    "name": "az",
    "date_order": "DMY",
    "january": [
        "yan",
        "yanvar"
    ],
    "february": [
        "fev",
        "fevral"
    ],
    "march": [
        "mar",
        "mart"
    ],
    "april": [
        "apr",
        "aprel"
    ],
    "may": [
        "may"
    ],
    "june": [
        "iyn",
        "iyun",
        "i̇yun"
    ],
    "july": [
        "iyl",
        "iyul",
        "i̇yul"
    ],
    "august": [
        "avq",
        "avqust"
    ],
    "september": [
        "sen",
        "sentyabr"
    ],
    "october": [
        "okt",
        "oktyabr"
    ],
    "november": [
        "noy",
        "noyabr"
    ],
    "december": [
        "dek",
        "dekabr"
    ],
    "monday": [
        "bazar ertəsi",
        "be"
    ],
    "tuesday": [
        "ça",
        "çərşənbə axşamı"
    ],
    "wednesday": [
        "ç",
        "çərşənbə"
    ],
    "thursday": [
        "ca",
        "cümə axşamı"
    ],
    "friday": [
        "c",
        "cümə"
    ],
    "saturday": [
        "ş",
        "şənbə"
    ],
    "sunday": [
        "b",
        "bazar"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "il",
        "i̇l"
    ],
    "month": [
        "ay"
    ],
    "week": [
        "həftə"
    ],
    "day": [
        "gün"
    ],
    "hour": [
        "saat"
    ],
    "minute": [
        "dəq",
        "dəqiqə"
    ],
    "second": [
        "san",
        "saniyə"
    ],
    "relative-type": {
        "0 day ago": [
            "bu gün"
        ],
        "0 hour ago": [
            "bu saat"
        ],
        "0 minute ago": [
            "bu dəqiqə"
        ],
        "0 month ago": [
            "bu ay"
        ],
        "0 second ago": [
            "indi"
        ],
        "0 week ago": [
            "bu həftə"
        ],
        "0 year ago": [
            "bu il"
        ],
        "1 day ago": [
            "dünən"
        ],
        "1 month ago": [
            "keçən ay"
        ],
        "1 week ago": [
            "keçən həftə"
        ],
        "1 year ago": [
            "keçən il"
        ],
        "in 1 day": [
            "sabah"
        ],
        "in 1 month": [
            "gələn ay"
        ],
        "in 1 week": [
            "gələn həftə"
        ],
        "in 1 year": [
            "gələn il"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) gün öncə"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) saat öncə"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) dəqiqə öncə"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) ay öncə"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) saniyə öncə"
        ],
        "\\1 week ago": [
            "(\\d+[.,]?\\d*) həftə öncə"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) il öncə"
        ],
        "in \\1 day": [
            "(\\d+[.,]?\\d*) gün ərzində"
        ],
        "in \\1 hour": [
            "(\\d+[.,]?\\d*) saat ərzində"
        ],
        "in \\1 minute": [
            "(\\d+[.,]?\\d*) dəqiqə ərzində"
        ],
        "in \\1 month": [
            "(\\d+[.,]?\\d*) ay ərzində"
        ],
        "in \\1 second": [
            "(\\d+[.,]?\\d*) saniyə ərzində"
        ],
        "in \\1 week": [
            "(\\d+[.,]?\\d*) həftə ərzində"
        ],
        "in \\1 year": [
            "(\\d+[.,]?\\d*) il ərzində"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
