info = {
    "name": "ha",
    "date_order": "DMY",
    "january": [
        "jan",
        "janairu"
    ],
    "february": [
        "fab",
        "faburairu"
    ],
    "march": [
        "mar",
        "maris"
    ],
    "april": [
        "afi",
        "afirilu"
    ],
    "may": [
        "may",
        "mayu"
    ],
    "june": [
        "yun",
        "yuni"
    ],
    "july": [
        "yul",
        "yuli"
    ],
    "august": [
        "agu",
        "agusta"
    ],
    "september": [
        "sat",
        "satumba"
    ],
    "october": [
        "okt",
        "oktoba"
    ],
    "november": [
        "nuw",
        "nuwamba"
    ],
    "december": [
        "dis",
        "disamba"
    ],
    "monday": [
        "lit",
        "litinin"
    ],
    "tuesday": [
        "tal",
        "talata"
    ],
    "wednesday": [
        "lar",
        "laraba"
    ],
    "thursday": [
        "alh",
        "alhamis"
    ],
    "friday": [
        "jum",
        "jumma'a"
    ],
    "saturday": [
        "asa",
        "asabar"
    ],
    "sunday": [
        "lah",
        "lahadi"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "shekara"
    ],
    "month": [
        "wata"
    ],
    "week": [
        "mako"
    ],
    "day": [
        "kwana"
    ],
    "hour": [
        "awa"
    ],
    "minute": [
        "minti"
    ],
    "second": [
        "daƙiƙa"
    ],
    "relative-type": {
        "0 day ago": [
            "yau"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "jiya"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "gobe"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {
        "ha-GH": {
            "name": "ha-GH"
        },
        "ha-NE": {
            "name": "ha-NE"
        }
    },
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
