info = {
    "name": "rn",
    "date_order": "DMY",
    "january": [
        "mut",
        "nzero"
    ],
    "february": [
        "gas",
        "ruhuhuma"
    ],
    "march": [
        "ntwarante",
        "wer"
    ],
    "april": [
        "mat",
        "ndamukiza"
    ],
    "may": [
        "gic",
        "rusama"
    ],
    "june": [
        "kam",
        "ruheshi"
    ],
    "july": [
        "mukakaro",
        "nya"
    ],
    "august": [
        "kan",
        "nyandagaro"
    ],
    "september": [
        "nyakanga",
        "nze"
    ],
    "october": [
        "gitugutu",
        "ukw"
    ],
    "november": [
        "munyonyo",
        "ugu"
    ],
    "december": [
        "kigarama",
        "uku"
    ],
    "monday": [
        "ku wa mbere",
        "mbe"
    ],
    "tuesday": [
        "kab",
        "ku wa kabiri"
    ],
    "wednesday": [
        "gtu",
        "ku wa gatatu"
    ],
    "thursday": [
        "kan",
        "ku wa kane"
    ],
    "friday": [
        "gnu",
        "ku wa gatanu"
    ],
    "saturday": [
        "gnd",
        "ku wa gatandatu"
    ],
    "sunday": [
        "cu",
        "ku w'indwi"
    ],
    "am": [
        "zmu"
    ],
    "pm": [
        "zmw"
    ],
    "year": [
        "umwaka"
    ],
    "month": [
        "ukwezi"
    ],
    "week": [
        "indwi, iyinga"
    ],
    "day": [
        "umusi"
    ],
    "hour": [
        "isaha"
    ],
    "minute": [
        "umunota"
    ],
    "second": [
        "isegonda"
    ],
    "relative-type": {
        "0 day ago": [
            "uyu musi"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "ejo (haheze)"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "ejo (hazoza)"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
