info = {
    "name": "af",
    "date_order": "YMD",
    "january": [
        "jan",
        "januarie"
    ],
    "february": [
        "feb",
        "februarie"
    ],
    "march": [
        "maart",
        "mrt"
    ],
    "april": [
        "apr",
        "april"
    ],
    "may": [
        "mei"
    ],
    "june": [
        "jun",
        "junie"
    ],
    "july": [
        "jul",
        "julie"
    ],
    "august": [
        "aug",
        "augustus"
    ],
    "september": [
        "sep",
        "september"
    ],
    "october": [
        "okt",
        "oktober"
    ],
    "november": [
        "nov",
        "november"
    ],
    "december": [
        "des",
        "desember"
    ],
    "monday": [
        "ma",
        "maandag"
    ],
    "tuesday": [
        "di",
        "dinsdag"
    ],
    "wednesday": [
        "wo",
        "woensdag"
    ],
    "thursday": [
        "do",
        "donderdag"
    ],
    "friday": [
        "vr",
        "vrydag"
    ],
    "saturday": [
        "sa",
        "saterdag"
    ],
    "sunday": [
        "so",
        "sondag"
    ],
    "am": [
        "vm"
    ],
    "pm": [
        "nm"
    ],
    "year": [
        "j",
        "jaar"
    ],
    "month": [
        "maand",
        "md"
    ],
    "week": [
        "week",
        "wk"
    ],
    "day": [
        "d",
        "dag"
    ],
    "hour": [
        "u",
        "uur"
    ],
    "minute": [
        "m",
        "min",
        "minuut"
    ],
    "second": [
        "s",
        "sek",
        "sekonde"
    ],
    "relative-type": {
        "0 day ago": [
            "vandag"
        ],
        "0 hour ago": [
            "hierdie uur"
        ],
        "0 minute ago": [
            "hierdie minuut"
        ],
        "0 month ago": [
            "vandeesmaand"
        ],
        "0 second ago": [
            "nou"
        ],
        "0 week ago": [
            "vandeesweek"
        ],
        "0 year ago": [
            "hierdie jaar"
        ],
        "1 day ago": [
            "gister"
        ],
        "1 month ago": [
            "verlede maand"
        ],
        "1 week ago": [
            "verlede week"
        ],
        "1 year ago": [
            "verlede jaar"
        ],
        "in 1 day": [
            "môre"
        ],
        "in 1 month": [
            "volgende maand"
        ],
        "in 1 week": [
            "volgende week"
        ],
        "in 1 year": [
            "volgende jaar"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) dae gelede",
            "(\\d+[.,]?\\d*) dag gelede"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) uur gelede"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) min gelede",
            "(\\d+[.,]?\\d*) minute gelede",
            "(\\d+[.,]?\\d*) minuut gelede"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) maand gelede",
            "(\\d+[.,]?\\d*) maande gelede",
            "(\\d+[.,]?\\d*) md gelede"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) sek gelede",
            "(\\d+[.,]?\\d*) sekonde gelede",
            "(\\d+[.,]?\\d*) sekondes gelede"
        ],
        "\\1 week ago": [
            "(\\d+[.,]?\\d*) w gelede",
            "(\\d+[.,]?\\d*) week gelede",
            "(\\d+[.,]?\\d*) weke gelede"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) jaar gelede"
        ],
        "in \\1 day": [
            "oor (\\d+[.,]?\\d*) dae",
            "oor (\\d+[.,]?\\d*) dag",
            "oor (\\d+[.,]?\\d*) minuut"
        ],
        "in \\1 hour": [
            "oor (\\d+[.,]?\\d*) uur"
        ],
        "in \\1 minute": [
            "oor (\\d+[.,]?\\d*) min",
            "oor (\\d+[.,]?\\d*) minuut"
        ],
        "in \\1 month": [
            "oor (\\d+[.,]?\\d*) md",
            "oor (\\d+[.,]?\\d*) minuut"
        ],
        "in \\1 second": [
            "oor (\\d+[.,]?\\d*) sek",
            "oor (\\d+[.,]?\\d*) sekonde",
            "oor (\\d+[.,]?\\d*) sekondes"
        ],
        "in \\1 week": [
            "oor (\\d+[.,]?\\d*) w",
            "oor (\\d+[.,]?\\d*) week",
            "oor (\\d+[.,]?\\d*) weke"
        ],
        "in \\1 year": [
            "oor (\\d+[.,]?\\d*) jaar"
        ]
    },
    "locale_specific": {
        "af-NA": {
            "name": "af-NA"
        }
    },
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
